==> mingw-w64-freecad-0.21.2-7.src.tar.zst: FreeCAD-0.21.2/src/App/Resources/translations/App_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk" sourcelanguage="en">
  <context>
    <name>LinkParams</name>
    <message>
      <location filename="../../Link.cpp" line="119"/>
      <source>Stores the last user choice of whether to apply CopyOnChange setup to all links
that reference the same configurable object</source>
      <translation type="unfinished">Stores the last user choice of whether to apply CopyOnChange setup to all links
that reference the same configurable object</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../Application.cpp" line="441"/>
      <source>Unnamed</source>
      <translation>Без назви</translation>
    </message>
  </context>
  <context>
    <name>App::Origin</name>
    <message>
      <location filename="../../Origin.cpp" line="140"/>
      <source>X-axis</source>
      <translation type="unfinished">X-axis</translation>
    </message>
    <message>
      <location filename="../../Origin.cpp" line="141"/>
      <source>Y-axis</source>
      <translation type="unfinished">Y-axis</translation>
    </message>
    <message>
      <location filename="../../Origin.cpp" line="142"/>
      <source>Z-axis</source>
      <translation type="unfinished">Z-axis</translation>
    </message>
    <message>
      <location filename="../../Origin.cpp" line="143"/>
      <source>XY-plane</source>
      <translation type="unfinished">XY-plane</translation>
    </message>
    <message>
      <location filename="../../Origin.cpp" line="144"/>
      <source>XZ-plane</source>
      <translation type="unfinished">XZ-plane</translation>
    </message>
    <message>
      <location filename="../../Origin.cpp" line="145"/>
      <source>YZ-plane</source>
      <translation type="unfinished">YZ-plane</translation>
    </message>
  </context>
  <context>
    <name>App::OriginGroupExtension</name>
    <message>
      <location filename="../../OriginGroupExtension.cpp" line="134"/>
      <source>Origin</source>
      <translation>Початок координат</translation>
    </message>
  </context>
</TS>

==> mingw-w64-freecad-1.0rc1-1.src.tar.zst: FreeCAD-1.0rc1/src/App/Resources/translations/App_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk" sourcelanguage="en">
  <context>
    <name>LinkParams</name>
    <message>
      <location filename="../../Link.cpp" line="118"/>
      <source>Stores the last user choice of whether to apply CopyOnChange setup to all links
that reference the same configurable object</source>
      <translation>Зберігає останній вибір користувача щодо того, чи застосовувати налаштування CopyOnChange до всіх посилань, які посилаються на той самий об'єкт, що налаштовується</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../Application.cpp" line="459"/>
      <source>Unnamed</source>
      <translation>Без назви</translation>
    </message>
  </context>
  <context>
    <name>App::Origin</name>
    <message>
      <location filename="../../Origin.cpp" line="142"/>
      <source>X-axis</source>
      <translation>Вісь X</translation>
    </message>
    <message>
      <location filename="../../Origin.cpp" line="143"/>
      <source>Y-axis</source>
      <translation>Вісь Y</translation>
    </message>
    <message>
      <location filename="../../Origin.cpp" line="144"/>
      <source>Z-axis</source>
      <translation>Вісь z</translation>
    </message>
    <message>
      <location filename="../../Origin.cpp" line="145"/>
      <source>XY-plane</source>
      <translation>Площина XY</translation>
    </message>
    <message>
      <location filename="../../Origin.cpp" line="146"/>
      <source>XZ-plane</source>
      <translation>Площина XZ</translation>
    </message>
    <message>
      <location filename="../../Origin.cpp" line="147"/>
      <source>YZ-plane</source>
      <translation>Площина YZ</translation>
    </message>
  </context>
  <context>
    <name>App::OriginGroupExtension</name>
    <message>
      <location filename="../../OriginGroupExtension.cpp" line="134"/>
      <source>Origin</source>
      <translation>Початок координат</translation>
    </message>
  </context>
</TS>
